//+------------------------------------------------------------------+
//|                               MQL4toMQL5_TechnicalIndicators.mqh |
//|                                                  Copyright keiji |
//|                                   http://www.dr-ea.com/meta-blog/|
//+------------------------------------------------------------------+
#property copyright "keiji"
#property link      "http://www.dr-ea.com/meta-blog/"


ENUM_TIMEFRAMES TFMigrate(int tf)
{
   switch(tf)
   {
      case 0: return(PERIOD_CURRENT);
      case 1: return(PERIOD_M1);
      case 5: return(PERIOD_M5);
      case 15: return(PERIOD_M15);
      case 30: return(PERIOD_M30);
      case 60: return(PERIOD_H1);
      case 240: return(PERIOD_H4);
      case 1440: return(PERIOD_D1);
      case 10080: return(PERIOD_W1);
      case 43200: return(PERIOD_MN1);
      
      case 2: return(PERIOD_M2);
      case 3: return(PERIOD_M3);
      case 4: return(PERIOD_M4);      
      case 6: return(PERIOD_M6);
      case 10: return(PERIOD_M10);
      case 12: return(PERIOD_M12);
      case 16385: return(PERIOD_H1);
      case 16386: return(PERIOD_H2);
      case 16387: return(PERIOD_H3);
      case 16388: return(PERIOD_H4);
      case 16390: return(PERIOD_H6);
      case 16392: return(PERIOD_H8);
      case 16396: return(PERIOD_H12);
      case 16408: return(PERIOD_D1);
      case 32769: return(PERIOD_W1);
      case 49153: return(PERIOD_MN1);      

      default: return(PERIOD_CURRENT);
   }
}

ENUM_MA_METHOD MethodMigrate(int method)
{
   switch(method)
   {
      case 0: return(MODE_SMA);
      case 1: return(MODE_EMA);
      case 2: return(MODE_SMMA);
      case 3: return(MODE_LWMA);   
      default: return(MODE_SMA); 
   }
}

ENUM_APPLIED_PRICE PriceMigrate(int price)
{
   switch(price)
   {
      case 1: return(PRICE_CLOSE);
      case 2: return(PRICE_OPEN);
      case 3: return(PRICE_HIGH);
      case 4: return(PRICE_LOW);    
      case 5: return(PRICE_MEDIAN);
      case 6: return(PRICE_TYPICAL);
      case 7: return(PRICE_WEIGHTED); 
      default: return(PRICE_CLOSE); 
   }
}

ENUM_STO_PRICE StoFieldMigrate(int field)
{
   switch(field)
   {
      case 0: return(STO_LOWHIGH);
      case 1: return(STO_CLOSECLOSE);
      default: return(STO_LOWHIGH); 
   }
}

//+------------------------------------------------------------------+
enum ALLIGATOR_MODE  { MODE_GATORJAW=1,   MODE_GATORTEETH, MODE_GATORLIPS };
enum ADX_MODE        { MODE_MAIN,         MODE_PLUSDI, MODE_MINUSDI };
enum UP_LOW_MODE     { MODE_BASE,         MODE_UPPER,      MODE_LOWER };
enum ICHIMOKU_MODE   { MODE_TENKANSEN=1,  MODE_KIJUNSEN, MODE_SENKOUSPANA, MODE_SENKOUSPANB, MODE_CHINKOUSPAN };
enum MAIN_SIGNAL_MODE{ MODE_MAIN,         MODE_SIGNAL };
//+------------------------------------------------------------------+
int handle;
double buf1[];
double buf2[];
double buf3[];
double buf4[];
double buf5[];

double CopyBuffer4(int index,int shift)
{
   switch(index)
   {
      case 0: if(CopyBuffer(handle,0,shift,1,buf1)>0) return(buf1[0]); break;
      case 1: if(CopyBuffer(handle,1,shift,1,buf2)>0) return(buf2[0]); break;
      case 2: if(CopyBuffer(handle,2,shift,1,buf3)>0) return(buf3[0]); break;
      case 3: if(CopyBuffer(handle,3,shift,1,buf4)>0) return(buf4[0]); break;
      case 4: if(CopyBuffer(handle,4,shift,1,buf5)>0) return(buf5[0]); break;
      default: break;
   }
   return(EMPTY_VALUE);
}

//iAC 
double iAC4( string symbol, int tf, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iAC(symbol, timeframe);
   return(CopyBuffer4(0,shift));
}
//iAD 
double iAD4( string symbol, int tf, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iAD(symbol, timeframe,VOLUME_TICK);
   return(CopyBuffer4(0,shift));
}
//iAlligator
double iAlligator4( string symbol, int tf, int jaw_period, int jaw_shift, int teeth_period, int teeth_shift, int lips_period, int lips_shift, int method, int price, int mode, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_MA_METHOD ma_method=MethodMigrate(method);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iAlligator(symbol,timeframe,jaw_period,jaw_shift,teeth_period,teeth_shift,lips_period,lips_shift,ma_method,applied_price);
   return(CopyBuffer4(mode-1,shift));
}
//iADX 
double iADX4( string symbol, int tf, int period, int price, int mode, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   //ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iADX(symbol,timeframe,period);  //...
   return(CopyBuffer4(mode,shift));
}
//iATR
double iATR4( string symbol, int tf, int period, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iATR(symbol, timeframe,period);
   return(CopyBuffer4(0,shift));
}
//iAO 
double iAO4( string symbol, int tf, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iAO(symbol, timeframe);
   return(CopyBuffer4(0,shift));
}
//iBearsPower 
double iBearsPower4( string symbol, int tf, int period, int price, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iBearsPower(symbol, timeframe,period);   //...
   return(CopyBuffer4(0,shift));
}
//iBands 
double iBands4( string symbol, int tf, int period, double deviation, int bands_shift, int method, int mode, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_MA_METHOD ma_method=MethodMigrate(method);
   handle=iBands(symbol, timeframe,period,bands_shift,deviation,ma_method);
   return(CopyBuffer4(mode,shift));
}
//iBandsOnArray 
//double iBandsOnArray( double array[], int total, int period, int deviation, int bands_shift, int mode, int shift) 

//iBullsPower 
double iBullsPower4( string symbol, int tf, int period, int price, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   //ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iBullsPower(symbol, timeframe,period);   //...
   return(CopyBuffer4(0,shift));
}
//iCCI 
double iCCI4( string symbol, int tf, int period, int price, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iCCI(symbol, timeframe,period,price);
   return(CopyBuffer4(0,shift));
}
//iCCIOnArray 
//double iCCIOnArray( double array[], int total, int period, int shift) 

//iCustom 
//double iCustom( string symbol, int tf, string name, ..., int mode, int shift) 

//iDeMarker 
double iDeMarker4( string symbol, int tf, int period, int shift)
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iDeMarker(symbol, timeframe,period);
   return(CopyBuffer4(0,shift));
} 
//iEnvelopes 
double iEnvelopes4( string symbol, int tf, int ma_period, int method, int ma_shift, int price, double deviation, int mode, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_MA_METHOD ma_method=MethodMigrate(method);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iEnvelopes(symbol,timeframe,ma_period,ma_shift,ma_method,applied_price,deviation);
   return(CopyBuffer4(mode-1,shift));
}
//iEnvelopesOnArray
//double iEnvelopesOnArray( double array[], int total, int ma_period, int ma_method, int ma_shift, double deviation, int mode, int shift) 

//iForce 
double iForce4( string symbol, int tf, int period, int method, int price, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_MA_METHOD ma_method=MethodMigrate(method);
   //ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iForce(symbol,timeframe,period,ma_method,VOLUME_TICK);
   return(CopyBuffer4(0,shift));
}
//iFractals 
double iFractals4( string symbol, int tf, int mode, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iFractals(symbol,timeframe);
   return(CopyBuffer4(mode-1,shift));
}
//iGator 
double iGator4( string symbol, int tf, int jaw_period, int jaw_shift, int teeth_period, int teeth_shift, int lips_period, int lips_shift, int method, int price, int mode, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_MA_METHOD ma_method=MethodMigrate(method);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iGator(symbol,timeframe,jaw_period,jaw_shift,teeth_period,teeth_shift,lips_period,lips_shift,ma_method,applied_price);
   return(CopyBuffer4(mode-1,shift));
}
//iIchimoku 
double iIchimoku4( string symbol, int tf, int tenkan_sen, int kijun_sen, int senkou_span_b, int mode, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iIchimoku(symbol,timeframe,tenkan_sen,kijun_sen,senkou_span_b);
   return(CopyBuffer4(mode-1,shift));
}
//iBWMFI 
double iBWMFI4( string symbol, int tf, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iBWMFI(symbol,timeframe,VOLUME_TICK);
   return(CopyBuffer4(0,shift));
}
//iMomentum 
double iMomentum4( string symbol, int tf, int period, int price, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iMomentum(symbol,timeframe,period,price);
   return(CopyBuffer4(0,shift));
}
//iMomentumOnArray 
//double iMomentumOnArray( double array[], int total, int period, int shift) 

//iMFI
double iMFI4( string symbol, int tf, int period, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iMFI(symbol,timeframe,period,VOLUME_TICK);
   return(CopyBuffer4(0,shift));
}
//iMA
double iMA4( string symbol, int tf, int period, int ma_shift, int method, int price, int shift)
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_MA_METHOD ma_method=MethodMigrate(method);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iMA(symbol, timeframe, period, ma_shift, ma_method, applied_price);
   return(CopyBuffer4(0,shift));
}
//iMAOnArray 
//double iMAOnArray( double array[], int total, int period, int ma_shift, int ma_method, int shift) 

//iOsMA 
double iOsMA4( string symbol, int tf, int fast_ema_period, int slow_ema_period, int signal_period, int price, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iOsMA(symbol, timeframe, fast_ema_period, slow_ema_period, signal_period, applied_price);
   return(CopyBuffer4(0,shift));
}
//iMACD 
double iMACD4(string symbol, int tf, int fast_ema_period, int slow_ema_period, int signal_period, int price, int mode, int shift)
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iMACD(symbol, timeframe, fast_ema_period, slow_ema_period, signal_period, applied_price);
   return(CopyBuffer4(mode,shift));
}
//iOBV 
double iOBV4( string symbol, int tf, int price, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iOBV(symbol, timeframe, VOLUME_TICK);
   return(CopyBuffer4(0,shift));
}
//iSAR 
double iSAR4( string symbol, int tf, double step, double maximum, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iSAR(symbol, timeframe, step, maximum);
   return(CopyBuffer4(0,shift));
}
//iRSI 
double iRSI4( string symbol, int tf, int period, int price, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iRSI(symbol, timeframe, period, applied_price);
   return(CopyBuffer4(0,shift));
} 
//iRSIOnArray 
//double iRSIOnArray( double array[], int total, int period, int shift) 
 
//iRVI 
double iRVI4( string symbol, int tf, int period, int mode, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iRVI(symbol, timeframe, period);
   return(CopyBuffer4(mode,shift));
}
//iStdDev 
double iStdDev4( string symbol, int tf, int ma_period, int ma_shift, int method, int price, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_MA_METHOD ma_method=MethodMigrate(method);
   ENUM_APPLIED_PRICE applied_price=PriceMigrate(price);
   handle=iStdDev(symbol, timeframe, ma_period, ma_shift, ma_method, applied_price);
   return(CopyBuffer4(0,shift));
} 
//iStdDevOnArray 
//double iStdDevOnArray( double array[], int total, int ma_period, int ma_shift, int ma_method, int shift) 

//iStochastic 
double iStochastic4( string symbol, int tf, int Kperiod, int Dperiod, int slowing, int method, int field, int mode, int shift) 
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   ENUM_MA_METHOD ma_method=MethodMigrate(method);
   ENUM_STO_PRICE price_field=StoFieldMigrate(field);
   handle=iStochastic(symbol, timeframe, Kperiod, Dperiod, slowing, ma_method, price_field);
   return(CopyBuffer4(mode,shift));
} 
//iWPR 
double iWPR4( string symbol, int tf, int period, int shift)
{
   ENUM_TIMEFRAMES timeframe=TFMigrate(tf);
   handle=iWPR(symbol, timeframe, period);
   return(CopyBuffer4(0,shift));
}
